/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calIImportExport.idl
 */

#ifndef __gen_calIImportExport_h__
#define __gen_calIImportExport_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class calIItemBase; /* forward declaration */

class nsIInputStream; /* forward declaration */

class nsIOutputStream; /* forward declaration */


/* starting interface:    calIFileType */
#define CALIFILETYPE_IID_STR "efef8333-e995-4f45-bdf7-bfcabbd9793e"

#define CALIFILETYPE_IID \
  {0xefef8333, 0xe995, 0x4f45, \
    { 0xbd, 0xf7, 0xbf, 0xca, 0xbb, 0xd9, 0x79, 0x3e }}

class NS_NO_VTABLE calIFileType : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALIFILETYPE_IID)

  /**
   * The default extension that should be associated 
   * with files of this type.
   */
  /* readonly attribute AString defaultExtension; */
  NS_IMETHOD GetDefaultExtension(nsAString & aDefaultExtension) = 0;

  /**
   * The extension filter to use in the filepicker's filter list.
   * Separate multiple extensions with semicolon and space. 
   * For example "*.html; *.htm".
   */
  /* readonly attribute AString extensionFilter; */
  NS_IMETHOD GetExtensionFilter(nsAString & aExtensionFilter) = 0;

  /**
   * The description to show to the user in the filter list.
   */
  /* readonly attribute AString description; */
  NS_IMETHOD GetDescription(nsAString & aDescription) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIFILETYPE \
  NS_IMETHOD GetDefaultExtension(nsAString & aDefaultExtension); \
  NS_IMETHOD GetExtensionFilter(nsAString & aExtensionFilter); \
  NS_IMETHOD GetDescription(nsAString & aDescription); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIFILETYPE(_to) \
  NS_IMETHOD GetDefaultExtension(nsAString & aDefaultExtension) { return _to GetDefaultExtension(aDefaultExtension); } \
  NS_IMETHOD GetExtensionFilter(nsAString & aExtensionFilter) { return _to GetExtensionFilter(aExtensionFilter); } \
  NS_IMETHOD GetDescription(nsAString & aDescription) { return _to GetDescription(aDescription); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIFILETYPE(_to) \
  NS_IMETHOD GetDefaultExtension(nsAString & aDefaultExtension) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultExtension(aDefaultExtension); } \
  NS_IMETHOD GetExtensionFilter(nsAString & aExtensionFilter) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetExtensionFilter(aExtensionFilter); } \
  NS_IMETHOD GetDescription(nsAString & aDescription) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDescription(aDescription); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIFileType
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIFILETYPE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIFileType)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* readonly attribute AString defaultExtension; */
NS_IMETHODIMP _MYCLASS_::GetDefaultExtension(nsAString & aDefaultExtension)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AString extensionFilter; */
NS_IMETHODIMP _MYCLASS_::GetExtensionFilter(nsAString & aExtensionFilter)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AString description; */
NS_IMETHODIMP _MYCLASS_::GetDescription(nsAString & aDescription)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    calIImporter */
#define CALIIMPORTER_IID_STR "dbe262ca-d6c6-4691-8d46-e7f6bbe632ec"

#define CALIIMPORTER_IID \
  {0xdbe262ca, 0xd6c6, 0x4691, \
    { 0x8d, 0x46, 0xe7, 0xf6, 0xbb, 0xe6, 0x32, 0xec }}

class NS_NO_VTABLE calIImporter : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALIIMPORTER_IID)

  /* void getFileTypes (out unsigned long aCount, [array, retval, size_is (aCount)] out calIFileType aTypes); */
  NS_IMETHOD GetFileTypes(PRUint32 *aCount, calIFileType ***aTypes) = 0;

  /* void importFromStream (in nsIInputStream aStream, out unsigned long aCount, [array, retval, size_is (aCount)] out calIItemBase aItems); */
  NS_IMETHOD ImportFromStream(nsIInputStream *aStream, PRUint32 *aCount, calIItemBase ***aItems) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIIMPORTER \
  NS_IMETHOD GetFileTypes(PRUint32 *aCount, calIFileType ***aTypes); \
  NS_IMETHOD ImportFromStream(nsIInputStream *aStream, PRUint32 *aCount, calIItemBase ***aItems); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIIMPORTER(_to) \
  NS_IMETHOD GetFileTypes(PRUint32 *aCount, calIFileType ***aTypes) { return _to GetFileTypes(aCount, aTypes); } \
  NS_IMETHOD ImportFromStream(nsIInputStream *aStream, PRUint32 *aCount, calIItemBase ***aItems) { return _to ImportFromStream(aStream, aCount, aItems); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIIMPORTER(_to) \
  NS_IMETHOD GetFileTypes(PRUint32 *aCount, calIFileType ***aTypes) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFileTypes(aCount, aTypes); } \
  NS_IMETHOD ImportFromStream(nsIInputStream *aStream, PRUint32 *aCount, calIItemBase ***aItems) { return !_to ? NS_ERROR_NULL_POINTER : _to->ImportFromStream(aStream, aCount, aItems); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIImporter
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIIMPORTER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIImporter)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void getFileTypes (out unsigned long aCount, [array, retval, size_is (aCount)] out calIFileType aTypes); */
NS_IMETHODIMP _MYCLASS_::GetFileTypes(PRUint32 *aCount, calIFileType ***aTypes)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void importFromStream (in nsIInputStream aStream, out unsigned long aCount, [array, retval, size_is (aCount)] out calIItemBase aItems); */
NS_IMETHODIMP _MYCLASS_::ImportFromStream(nsIInputStream *aStream, PRUint32 *aCount, calIItemBase ***aItems)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    calIExporter */
#define CALIEXPORTER_IID_STR "18c75bb3-6309-4c33-903f-6055fec39d07"

#define CALIEXPORTER_IID \
  {0x18c75bb3, 0x6309, 0x4c33, \
    { 0x90, 0x3f, 0x60, 0x55, 0xfe, 0xc3, 0x9d, 0x07 }}

class NS_NO_VTABLE calIExporter : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALIEXPORTER_IID)

  /* void getFileTypes (out unsigned long aCount, [array, retval, size_is (aCount)] out calIFileType aTypes); */
  NS_IMETHOD GetFileTypes(PRUint32 *aCount, calIFileType ***aTypes) = 0;

  /**
   * Export the items into the stream
   * 
   * @param aStream  the stream to put the data into
   * @param aCount   the number of items being exported
   * @param aItems   an array of items to be exported
   * @param aTitle   a title the exporter can choose to use
   */
  /* void exportToStream (in nsIOutputStream aStream, in unsigned long aCount, [array, size_is (aCount)] in calIItemBase aItems, in AString aTitle); */
  NS_IMETHOD ExportToStream(nsIOutputStream *aStream, PRUint32 aCount, calIItemBase **aItems, const nsAString & aTitle) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIEXPORTER \
  NS_IMETHOD GetFileTypes(PRUint32 *aCount, calIFileType ***aTypes); \
  NS_IMETHOD ExportToStream(nsIOutputStream *aStream, PRUint32 aCount, calIItemBase **aItems, const nsAString & aTitle); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIEXPORTER(_to) \
  NS_IMETHOD GetFileTypes(PRUint32 *aCount, calIFileType ***aTypes) { return _to GetFileTypes(aCount, aTypes); } \
  NS_IMETHOD ExportToStream(nsIOutputStream *aStream, PRUint32 aCount, calIItemBase **aItems, const nsAString & aTitle) { return _to ExportToStream(aStream, aCount, aItems, aTitle); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIEXPORTER(_to) \
  NS_IMETHOD GetFileTypes(PRUint32 *aCount, calIFileType ***aTypes) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFileTypes(aCount, aTypes); } \
  NS_IMETHOD ExportToStream(nsIOutputStream *aStream, PRUint32 aCount, calIItemBase **aItems, const nsAString & aTitle) { return !_to ? NS_ERROR_NULL_POINTER : _to->ExportToStream(aStream, aCount, aItems, aTitle); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIExporter
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIEXPORTER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIExporter)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void getFileTypes (out unsigned long aCount, [array, retval, size_is (aCount)] out calIFileType aTypes); */
NS_IMETHODIMP _MYCLASS_::GetFileTypes(PRUint32 *aCount, calIFileType ***aTypes)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void exportToStream (in nsIOutputStream aStream, in unsigned long aCount, [array, size_is (aCount)] in calIItemBase aItems, in AString aTitle); */
NS_IMETHODIMP _MYCLASS_::ExportToStream(nsIOutputStream *aStream, PRUint32 aCount, calIItemBase **aItems, const nsAString & aTitle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calIImportExport_h__ */
